tinp
#######

Builtin function ``input`` does not support scan formatted. Also, its return value can only be string. Users should do extra parsing actions and type conversions to get what they want.

This module provides several wrappers of builtin ``input``. They can statisfy above requirements easily.
